Create a streaming, updating [OHLC chart](https://en.wikipedia.org/wiki/Open-high-low-close_chart)
with [MACD indicator](https://en.wikipedia.org/wiki/MACD) from simulated market data.

#### Running

To view the app directly from a Bokeh server, navigate to the parent
directory [`examples/app`](https://github.com/bokeh/bokeh/tree/master/examples/app),
and execute the command:

    bokeh serve --show ohlc
